%========================================================================================================%
%                   Komandna datoteka startA.m pokrece SIMULINK model a.mdl                              %
%========================================================================================================%
clear; clc;
%--------------------------------------------------------------------------------------------------------%
T = 0.0003;                             % [s]; perioda odabiranja regulatora brzine
Wmax = 100*pi;                          % [rad/s]; max Wref
%--------------------------------------------------------------------------------------------------------%
% ELEKTRICNI PODSISTEM
Km = 1;                                 % pojacanje aktuatora
psi = 0.3;                              % faktor relativnog prigusenja elektricnog podsistema
Wn = 4430;                              % [rad/s]; neprigusena prirodna ucestanost 
                                        % elektricnog podsistema; 
Te = 1/(2*psi*Wn);                      % [s]; dominantna vremenska konstanta 
                                        % elektricnog podsistema; [izraz (10b)]
Tmax = 10;                              % [Nm]; maksimalna vrednost pokretackog momenta
%--------------------------------------------------------------------------------------------------------%
% PARAMETRI MEHANICKOG PODSISTEMA SA KRUTOM OSOVINOM
Jm = 0.0008;                            % [kgm2]; inercija elektricne masine
JL = 0.0002;                            % [kgm2]; inercija opterecenja
J = Jm + JL;                            % [kgm2]; ukupna inercija
%--------------------------------------------------------------------------------------------------------%
% DAVAC-ENKODER
N = 12;                                 % [broj bita]; rezolucija enkodera
Kn = 2^N/(2*pi);                        % prenosni odnos enkodera; [izraz (11)]
kvant = 1;                              % kvantizacioni interval enkodera
%--------------------------------------------------------------------------------------------------------%
% DOMINANTNA VREMENSKA KONSTANTA
Tau = Te;                               % [izraz (35)]
%--------------------------------------------------------------------------------------------------------%
% REGULATOR BRZINE
Nreg = 24;                              % [broj bita]; tacnost regulatora brzine
% PRORACUN PARAMETARA REGULATORA BRZINE
b = exp(-T/Tau);                        % parametar BETA; [izraz (34)]
C = (Km*Kn*T)/(2*J);                    % sinteticki koeficijent; [izraz (33c)]      
Sopt = (4 + 4*b)^(1/3) - 1;             % optimalni trostruki pol brzinskog servomehanizma; [izraz (45)]
KP = (Sopt^3 - b)/((1 - b)*C);          % koeficijent proporcionalnog dejstva; [izraz (46)]   
KI = (3*Sopt^2 - 1 - 2*b)/((1 - b)*C);  % koeficijent integralnog dejstva; [izraz (46)]
freg = -log(Sopt)/(2*pi*T);             % propusni opseg brzinske petlje; [izraz (47)]
%--------------------------------------------------------------------------------------------------------%
% START MODELA a.mdl
open_system('a.mdl');
open_system('a/TRACE/trace');
%--------------------------------------------------------------------------------------------------------%

